@@ -1,7 +1,7 @@
 /*GPL*START*
  * mp3check - check mp3 file for consistency and print infos
  * 
- * Copyright (C) 1998-2005 by Johannes Overmann <Johannes.Overmann@gmx.de>
+ * Copyright (C) 1998-2005,2008-2009 by Johannes Overmann <Johannes.Overmann@gmx.de>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,18 +30,20 @@
 #include "crc16.h"
 #include "id3tag.h"
 #include "tfiletools.h"
-#include "config.h"
 
 
 
 #define ONLY_MP3 "mp3,MP3,Mp3,mP3"
 
+// please update also HISTORY
+#define VERSION "0.8.7"
+
 
 const char *options[] = {
    "#usage='Usage: [OPTIONS, FILES AND DIRECTORIES] [--] [FILES AND DIRECTORIES]\n\n"
      "this program checks audio mpeg layer 1,2 and 3 (*.mp3) files for\n"       
      "consistency (headers and crc) and anomalies'",
-   "#trailer='\n%n version %v *** (C) 1998-2003 by Johannes Overmann\ncomments, bugs and suggestions welcome: %e\n%gpl'",
+   "#trailer='\n%n version %v *** (C) 1998-2003,2005,2008-2009,2012 by Johannes Overmann\ncomments, bugs and suggestions welcome: %e\n%gpl'",
    "#stopat--",
    "#onlycl",					 
    // options
@@ -141,7 +143,7 @@ const char *c_nor = "\033[0m";
 
 // minimum number of sequential valid and constant frame headers to validate header
 const int MIN_VALID = 6;
-
+const int LIST_MAX_HEADER_SEARCH = 1024*1024; // search max 1MB for --list --compact-list --raw-list
 
 // global data
 bool progress = false;
@@ -270,7 +272,9 @@ struct Header {
    }
    
    bool sameConstant(Header h) const {
-      if((*(unsigned int*)this) == (*(unsigned int*)&h)) return true;
+      const unsigned int *p1 = (unsigned int*)this;
+      const unsigned int *p2 = (unsigned int*)(&h);
+      if(*p1 == *p2) return true;
       if((syncword          ==h.syncword          ) &&
 	 (ID                ==h.ID                ) &&
 	 (layer_index       ==h.layer_index       ) &&
@@ -1584,7 +1588,7 @@ int main(int argc, char *argv[]) {
       // list
       if(ac("list")||ac("compact-list")||ac("raw-list")) {
 	 // speed up list of very large files (like *.wav)
-	 int maxl = 128*1024; // search max 128k
+	 int maxl = LIST_MAX_HEADER_SEARCH;
 	 int start = find_next_header(p, len<maxl?len:maxl, MIN_VALID);
 	 if(start<0) {
 	    if(!ign_noamp) {
