@@ -1282,7 +1282,7 @@ bool TAppConfig::save(tstring *rc_name_out) {
 	    j = line.firstOccurence('=');
 	    if(j == tstring::npos) {
 	       line.cropSpace();
-	       for(j = 0; j < line.len() && (!isspace(line[j])); j++);
+	       for(j = 0; j < line.len() && (!isspace(line[j])); j++) /*empty body*/;
 	    }
 	    line.truncate(j);
 	    upd:
