@@ -54,11 +54,11 @@ class tmap: public tmap_base<K,T> {
    // new functionality
 
    /// return whether an element with key is contained or not
-    bool contains(const K& key) const { return find(key) != tmap_base<K,T>::end(); }
+    bool contains(const K& key) const { return this->find(key) != tmap_base<K,T>::end(); }
    /// access element read only (const)
 // g++ 2.95.2 does not allow this:
-// const T& operator[](const K& key) const { const_iterator i = find(key); if(i != end()) return i->second; else throw TNotFoundException(); } // throw(TNotFoundException)
-   const T& operator[](const K& key) const { if(contains(key)) return find(key)->second; else throw TNotFoundException(); } // throw(TNotFoundException)
+// const T& operator[](const K& key) const { const_iterator i = this->find(key); if(i != end()) return i->second; else throw TNotFoundException(); } // throw(TNotFoundException)
+   const T& operator[](const K& key) const { if(contains(key)) return this->find(key)->second; else throw TNotFoundException(); } // throw(TNotFoundException)
 };
 
 
