@@ -1134,7 +1134,7 @@ void tstring::translateChar(char from, char to) {
 size_t tstring::firstOccurence(char c) const {
    size_t i;
    
-   for(i = 0; (i < rep->len) && ((*rep)[i] != c); ++i);
+   for(i = 0; (i < rep->len) && ((*rep)[i] != c); ++i) /* empty body */;
    if(i < rep->len) return i;
    else return npos;
 }
@@ -1270,7 +1270,7 @@ const char *progressBar(const char *message, unsigned int n, unsigned int max, i
     
    // get num chars for number and max
    int nlen = 0, i;
-   for(i = max; i; i /= 10, nlen++);
+   for(i = max; i; i /= 10, nlen++) /* empty body */;
    
    int l = sprintf(buf, "%.*s %*d/%*d (%5.1f%%) ", width - (12 + 2 * nlen), message, nlen, n, nlen, max, double(n)/double(max)*100.0);
    int rest = width - l;
@@ -1343,7 +1343,7 @@ tvector<tstring> loadTextFile(const char *fname) {
    FILE *f = fopen(fname, "r");
    if(f==0) throw TFileOperationErrnoException(fname, "fopen(mode='r')", errno);
    tvector<tstring> r;
-   for(size_t i = 0; r[i].readLine(f); i++);
+   for(size_t i = 0; r[i].readLine(f); i++) /* empty body */;
    fclose(f);
    r.pop_back();
    return r;
@@ -1352,7 +1352,7 @@ tvector<tstring> loadTextFile(const char *fname) {
 
 tvector<tstring> loadTextFile(FILE *file) {
    tvector<tstring> r;
-   for(size_t i = 0; r[i].readLine(file); i++);
+   for(size_t i = 0; r[i].readLine(file); i++) /* empty body */;
    r.pop_back();
    return r;
 }
