@@ -58,15 +58,15 @@ class tvector: public tvector_base<T> {
    // new functionality
    
    /// append an element to the end
-   const tvector& operator += (const T& a) { push_back(a); return *this; }
+   const tvector& operator += (const T& a) { this->push_back(a); return *this; }
    /// append another tvector to the end
-   const tvector& operator += (const tvector& a) { insert(tvector_base<T>::end(), a.tvector_base<T>::begin(), a.tvector_base<T>::end()); return *this; }
+   const tvector& operator += (const tvector& a) { this->insert(tvector_base<T>::end(), a.tvector_base<T>::begin(), a.tvector_base<T>::end()); return *this; }
    /// direct read only access, safe
    const T& operator[](size_t i) const { if(i < tvector_base<T>::size()) return tvector_base<T>::operator[](i); else throw TZeroBasedIndexOutOfRangeException(i, tvector_base<T>::size()); } // throw(TZeroBasedIndexOutOfRangeException);
    /// direct read/write access, automatically create new elements
    T& operator[](size_t i) { if(i >= tvector_base<T>::size()) operator+=(tvector(i - tvector_base<T>::size() + 1)); return tvector_base<T>::operator[](i); }
    /// clear vector
-   void clear() { erase(tvector_base<T>::begin(), tvector_base<T>::end()); }
+   void clear() { this->erase(tvector_base<T>::begin(), tvector_base<T>::end()); }
 };
 
 
